@@ -27,6 +27,7 @@
 #include <libpeas/peas.h>
 
 #include "ide-clone-surface.h"
+#include "ide-greeter-buttons-section.h"
 #include "ide-greeter-private.h"
 #include "ide-greeter-workspace.h"
 
@@ -46,26 +47,30 @@
 
 struct _IdeGreeterWorkspace
 {
-  IdeWorkspace       parent_instance;
+  IdeWorkspace              parent_instance;
 
-  PeasExtensionSet  *addins;
-  DzlPatternSpec    *pattern_spec;
-  GSimpleAction     *delete_action;
-  GSimpleAction     *purge_action;
+  PeasExtensionSet         *addins;
+  DzlPatternSpec           *pattern_spec;
+  GSimpleAction            *delete_action;
+  GSimpleAction            *purge_action;
 
   /* Template Widgets */
-  IdeCloneSurface   *clone_surface;
-  IdeHeaderBar      *header_bar;
-  DzlPriorityBox    *sections;
-  DzlPriorityBox    *left_box;
-  GtkStack          *surfaces;
-  IdeSurface        *sections_surface;
-  GtkSearchEntry    *search_entry;
-  GtkButton         *back_button;
-  GtkButton         *select_button;
-  GtkActionBar      *action_bar;
+  IdeCloneSurface          *clone_surface;
+  IdeHeaderBar             *header_bar;
+  DzlPriorityBox           *sections;
+  DzlPriorityBox           *left_box;
+  GtkStack                 *surfaces;
+  IdeSurface               *sections_surface;
+  GtkSearchEntry           *search_entry;
+  GtkButton                *back_button;
+  GtkButton                *select_button;
+  GtkActionBar             *action_bar;
+  GtkActionBar             *projects_action_bar;
+  GtkLabel                 *title;
+  IdeGreeterButtonsSection *buttons_section;
+  DzlEmptyState            *empty_state;
 
-  guint              selection_mode : 1;
+  guint                     selection_mode : 1;
 };
 
 G_DEFINE_TYPE (IdeGreeterWorkspace, ide_greeter_workspace, IDE_TYPE_WORKSPACE)
@@ -78,6 +83,31 @@ enum {
 
 static GParamSpec *properties [N_PROPS];
 
+static void
+ide_greeter_workspace_has_match_cb (GtkWidget *widget,
+                                    gpointer   user_data)
+{
+  gboolean *match = user_data;
+
+  if (IDE_IS_GREETER_SECTION (widget))
+    *match |= gtk_widget_get_visible (widget);
+}
+
+static gboolean
+ide_greeter_workspace_has_match (IdeGreeterWorkspace *self)
+{
+  gboolean match = FALSE;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (IDE_IS_GREETER_WORKSPACE (self));
+
+  gtk_container_foreach (GTK_CONTAINER (self->sections),
+                         ide_greeter_workspace_has_match_cb,
+                         &match);
+
+  return match;
+}
+
 static void
 ide_greeter_workspace_filter_sections (PeasExtensionSet *set,
                                        PeasPluginInfo   *plugin_info,
@@ -116,6 +146,9 @@ ide_greeter_workspace_apply_filter_all (IdeGreeterWorkspace *self)
     peas_extension_set_foreach (self->addins,
                                 ide_greeter_workspace_filter_sections,
                                 self);
+
+  gtk_widget_set_visible (GTK_WIDGET (self->empty_state),
+                          !ide_greeter_workspace_has_match (self));
 }
 
 static void
@@ -181,7 +214,7 @@ stack_notify_visible_child_cb (IdeGreeterWorkspace *self,
   if (DZL_IS_DOCK_ITEM (visible_child))
     title = dzl_dock_item_get_title (DZL_DOCK_ITEM (visible_child));
 
-  gtk_header_bar_set_title (GTK_HEADER_BAR (self->header_bar), title);
+  gtk_label_set_label (self->title, title);
 
   sections = ide_str_equal0 ("sections", gtk_stack_get_visible_child_name (stack));
 
@@ -585,16 +618,21 @@ ide_greeter_workspace_class_init (IdeGreeterWorkspaceClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/builder/ui/ide-greeter-workspace.ui");
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, action_bar);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, back_button);
+  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, buttons_section);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, clone_surface);
+  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, empty_state);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, header_bar);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, left_box);
+  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, projects_action_bar);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, search_entry);
+  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, sections);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, select_button);
   gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, surfaces);
-  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, sections);
+  gtk_widget_class_bind_template_child (widget_class, IdeGreeterWorkspace, title);
   gtk_widget_class_bind_template_callback (widget_class, stack_notify_visible_child_cb);
 
   g_type_ensure (IDE_TYPE_CLONE_SURFACE);
+  g_type_ensure (IDE_TYPE_GREETER_BUTTONS_SECTION);
 }
 
 static void
@@ -665,6 +703,12 @@ ide_greeter_workspace_add_section (IdeGreeterWorkspace *self,
   gtk_container_add_with_properties (GTK_CONTAINER (self->sections), GTK_WIDGET (section),
                                      "priority", ide_greeter_section_get_priority (section),
                                      NULL);
+
+  gtk_widget_set_visible (GTK_WIDGET (section),
+                          ide_greeter_section_filter (section, NULL));
+
+  gtk_widget_set_visible (GTK_WIDGET (self->empty_state),
+                          !ide_greeter_workspace_has_match (self));
 }
 
 /**
@@ -698,9 +742,7 @@ ide_greeter_workspace_add_button (IdeGreeterWorkspace *self,
   g_return_if_fail (IDE_IS_GREETER_WORKSPACE (self));
   g_return_if_fail (GTK_IS_WIDGET (button));
 
-  gtk_container_add_with_properties (GTK_CONTAINER (self->left_box), button,
-                                     "priority", priority,
-                                     NULL);
+  ide_greeter_buttons_section_add_button (self->buttons_section, priority, button);
 }
 
 /**
@@ -803,6 +845,7 @@ ide_greeter_workspace_set_selection_mode (IdeGreeterWorkspace *self,
                              ide_greeter_workspace_set_selection_mode_cb,
                              GINT_TO_POINTER (selection_mode));
       gtk_widget_set_visible (GTK_WIDGET (self->action_bar), selection_mode);
+      gtk_widget_set_visible (GTK_WIDGET (self->projects_action_bar), !selection_mode);
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_SELECTION_MODE]);
     }
 }
