@@ -1,6 +1,6 @@
 /* ide-source-search-context.c
  *
- * Copyright © 2018 Christian Hergert <chergert@redhat.com>
+ * Copyright 2018-2019 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,14 +14,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include "config.h"
-
 #define G_LOG_DOMAIN "ide-source-search-context"
 
-#include "sourceview/ide-source-search-context.h"
-#include "threading/ide-task.h"
+#include "config.h"
+
+#include <libide-threading.h>
+
+#include "ide-source-search-context.h"
 
 typedef struct
 {
@@ -58,6 +61,8 @@ search_data_free (SearchData *sd)
  * and we can remove this.
  *
  * https://gitlab.gnome.org/GNOME/gtksourceview/issues/8
+ *
+ * Since: 3.32
  */
 void
 ide_source_search_context_backward_async (GtkSourceSearchContext *search,
@@ -111,7 +116,7 @@ ide_source_search_context_backward_async (GtkSourceSearchContext *search,
  * @has_wrapped_around: (out): a location to a boolean
  * @error: a location for a #GError
  *
- * Since: 3.30
+ * Since: 3.32
  */
 gboolean
 ide_source_search_context_backward_finish2 (GtkSourceSearchContext  *search,
