@@ -33,6 +33,7 @@ struct _GbpMesonBuildSystem
   GFile              *project_file;
   IdeCompileCommands *compile_commands;
   GFileMonitor       *monitor;
+  gchar              *project_version;
 };
 
 static void async_initable_iface_init (GAsyncInitableIface     *iface);
@@ -63,7 +64,7 @@ gbp_meson_build_system_ensure_config_cb (GObject      *object,
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (IDE_IS_TASK (task));
 
-  if (!ide_build_manager_execute_finish (build_manager, result, &error))
+  if (!ide_build_manager_build_finish (build_manager, result, &error))
     ide_task_return_error (task, g_steal_pointer (&error));
   else
     ide_task_return_boolean (task, TRUE);
@@ -89,8 +90,8 @@ gbp_meson_build_system_ensure_config_async (GbpMesonBuildSystem *self,
   context = ide_object_get_context (IDE_OBJECT (self));
   build_manager = ide_build_manager_from_context (context);
 
-  ide_build_manager_execute_async (build_manager,
-                                   IDE_BUILD_PHASE_CONFIGURE,
+  ide_build_manager_build_async (build_manager,
+                                   IDE_PIPELINE_PHASE_CONFIGURE,
                                    NULL,
                                    cancellable,
                                    gbp_meson_build_system_ensure_config_cb,
@@ -191,7 +192,7 @@ gbp_meson_build_system_load_commands_config_cb (GObject      *object,
   g_autoptr(GFile) file = NULL;
   g_autofree gchar *path = NULL;
   IdeBuildManager *build_manager;
-  IdeBuildPipeline *pipeline;
+  IdePipeline *pipeline;
   GCancellable *cancellable;
   IdeContext *context;
 
@@ -219,7 +220,7 @@ gbp_meson_build_system_load_commands_config_cb (GObject      *object,
       return;
     }
 
-  path = ide_build_pipeline_build_builddir_path (pipeline, "compile_commands.json", NULL);
+  path = ide_pipeline_build_builddir_path (pipeline, "compile_commands.json", NULL);
 
   if (!g_file_test (path, G_FILE_TEST_IS_REGULAR))
     {
@@ -253,15 +254,16 @@ gbp_meson_build_system_load_commands_async (GbpMesonBuildSystem *self,
   g_autoptr(IdeTask) task = NULL;
   g_autofree gchar *path = NULL;
   IdeBuildManager *build_manager;
-  IdeBuildPipeline *pipeline;
+  IdePipeline *pipeline;
   IdeContext *context;
 
+  IDE_ENTRY;
+
   g_assert (GBP_IS_MESON_BUILD_SYSTEM (self));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   task = ide_task_new (self, cancellable, callback, user_data);
   ide_task_set_source_tag (task, gbp_meson_build_system_load_commands_async);
-  ide_task_set_priority (task, G_PRIORITY_LOW);
 
   /*
    * If we've already load the compile commands database, use it and
@@ -274,7 +276,7 @@ gbp_meson_build_system_load_commands_async (GbpMesonBuildSystem *self,
       ide_task_return_pointer (task,
                                g_object_ref (self->compile_commands),
                                g_object_unref);
-      return;
+      IDE_EXIT;
     }
 
   /*
@@ -292,16 +294,16 @@ gbp_meson_build_system_load_commands_async (GbpMesonBuildSystem *self,
    * here about whether or not it is setup fully. It may be delayed due
    * to device initialization.
    */
-  if (pipeline == NULL || !ide_build_pipeline_is_ready (pipeline))
+  if (pipeline == NULL)
     {
       ide_task_return_new_error (task,
                                  G_IO_ERROR,
                                  G_IO_ERROR_NOT_INITIALIZED,
-                                 "The pipeline is not yet ready to handle requests");
-      return;
+                                 "There is no pipeline to access");
+      IDE_EXIT;
     }
 
-  path = ide_build_pipeline_build_builddir_path (pipeline, "compile_commands.json", NULL);
+  path = ide_pipeline_build_builddir_path (pipeline, "compile_commands.json", NULL);
 
   if (g_file_test (path, G_FILE_TEST_IS_REGULAR))
     {
@@ -319,7 +321,21 @@ gbp_meson_build_system_load_commands_async (GbpMesonBuildSystem *self,
 
       gbp_meson_build_system_monitor (self, file);
 
-      return;
+      IDE_EXIT;
+    }
+
+  /*
+   * Because we're accessing the pipeline directly, we need to be careful
+   * here about whether or not it is setup fully. It may be delayed due
+   * to device initialization.
+   */
+  if (!ide_pipeline_is_ready (pipeline))
+    {
+      ide_task_return_new_error (task,
+                                 G_IO_ERROR,
+                                 G_IO_ERROR_NOT_INITIALIZED,
+                                 "The pipeline is not yet ready to handle requests");
+      IDE_EXIT;
     }
 
   /*
@@ -332,6 +348,8 @@ gbp_meson_build_system_load_commands_async (GbpMesonBuildSystem *self,
                                               cancellable,
                                               gbp_meson_build_system_load_commands_config_cb,
                                               g_steal_pointer (&task));
+
+  IDE_EXIT;
 }
 
 static IdeCompileCommands *
@@ -345,6 +363,24 @@ gbp_meson_build_system_load_commands_finish (GbpMesonBuildSystem  *self,
   return ide_task_propagate_pointer (IDE_TASK (result), error);
 }
 
+static void
+gbp_meson_build_system_set_project_file (GbpMesonBuildSystem *self,
+                                         GFile               *file)
+{
+  g_autofree gchar *name = NULL;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (GBP_IS_MESON_BUILD_SYSTEM (self));
+  g_assert (G_IS_FILE (file));
+
+  name = g_file_get_basename (file);
+
+  if (ide_str_equal0 (name, "meson.build"))
+    self->project_file = g_file_dup (file);
+  else
+    self->project_file = g_file_get_child (file, "meson.build");
+}
+
 static void
 gbp_meson_build_system_finalize (GObject *object)
 {
@@ -353,6 +389,7 @@ gbp_meson_build_system_finalize (GObject *object)
   g_clear_object (&self->project_file);
   g_clear_object (&self->compile_commands);
   g_clear_object (&self->monitor);
+  g_clear_pointer (&self->project_version, g_free);
 
   G_OBJECT_CLASS (gbp_meson_build_system_parent_class)->finalize (object);
 }
@@ -387,7 +424,7 @@ gbp_meson_build_system_set_property (GObject      *object,
   switch (prop_id)
     {
     case PROP_PROJECT_FILE:
-      self->project_file = g_value_dup_object (value);
+      gbp_meson_build_system_set_project_file (self, g_value_get_object (value));
       break;
 
     default:
@@ -448,8 +485,8 @@ gbp_meson_build_system_get_build_flags_for_files_cb (GObject      *object,
   g_autoptr(GError) error = NULL;
   g_autoptr(GHashTable) ret = NULL;
   g_auto(GStrv) system_includes = NULL;
-  IdeConfigurationManager *config_manager;
-  IdeConfiguration *config;
+  IdeConfigManager *config_manager;
+  IdeConfig *config;
   IdeContext *context;
   IdeRuntime *runtime;
   GPtrArray *files;
@@ -469,9 +506,9 @@ gbp_meson_build_system_get_build_flags_for_files_cb (GObject      *object,
 
   /* Get non-standard system includes */
   context = ide_object_get_context (IDE_OBJECT (self));
-  config_manager = ide_configuration_manager_from_context (context);
-  config = ide_configuration_manager_get_current (config_manager);
-  if (NULL != (runtime = ide_configuration_get_runtime (config)))
+  config_manager = ide_config_manager_from_context (context);
+  config = ide_config_manager_get_current (config_manager);
+  if (NULL != (runtime = ide_config_get_runtime (config)))
     system_includes = ide_runtime_get_system_include_dirs (runtime);
 
   ret = g_hash_table_new_full (g_file_hash,
@@ -505,9 +542,9 @@ gbp_meson_build_system_get_build_flags_cb (GObject      *object,
   g_autoptr(GFile) directory = NULL;
   g_auto(GStrv) system_includes = NULL;
   g_auto(GStrv) ret = NULL;
-  IdeConfigurationManager *config_manager;
+  IdeConfigManager *config_manager;
   IdeContext *context;
-  IdeConfiguration *config;
+  IdeConfig *config;
   IdeRuntime *runtime;
   GFile *file;
 
@@ -528,9 +565,9 @@ gbp_meson_build_system_get_build_flags_cb (GObject      *object,
 
   /* Get non-standard system includes */
   context = ide_object_get_context (IDE_OBJECT (self));
-  config_manager = ide_configuration_manager_from_context (context);
-  config = ide_configuration_manager_get_current (config_manager);
-  if (NULL != (runtime = ide_configuration_get_runtime (config)))
+  config_manager = ide_config_manager_from_context (context);
+  config = ide_config_manager_get_current (config_manager);
+  if (NULL != (runtime = ide_config_get_runtime (config)))
     system_includes = ide_runtime_get_system_include_dirs (runtime);
 
   ret = ide_compile_commands_lookup (compile_commands,
@@ -633,22 +670,22 @@ gbp_meson_build_system_get_build_flags_for_files_finish (IdeBuildSystem  *build_
 
 static gchar *
 gbp_meson_build_system_get_builddir (IdeBuildSystem   *build_system,
-                                     IdeBuildPipeline *pipeline)
+                                     IdePipeline *pipeline)
 {
   GbpMesonBuildSystem *self = (GbpMesonBuildSystem *)build_system;
-  IdeConfiguration *config;
+  IdeConfig *config;
   IdeBuildLocality locality;
 
   g_assert (GBP_IS_MESON_BUILD_SYSTEM (self));
-  g_assert (IDE_IS_BUILD_PIPELINE (pipeline));
+  g_assert (IDE_IS_PIPELINE (pipeline));
 
   /*
    * If the build configuration requires that we do an in tree build (yuck),
    * then use "_build" as our build directory to build in-tree.
    */
 
-  config = ide_build_pipeline_get_configuration (pipeline);
-  locality = ide_configuration_get_locality (config);
+  config = ide_pipeline_get_config (pipeline);
+  locality = ide_config_get_locality (config);
 
   if ((locality & IDE_BUILD_LOCALITY_OUT_OF_TREE) == 0)
     {
@@ -675,6 +712,17 @@ gbp_meson_build_system_supports_toolchain (IdeBuildSystem *self,
   return FALSE;
 }
 
+static gchar *
+gbp_meson_build_system_get_project_version (IdeBuildSystem *build_system)
+{
+  GbpMesonBuildSystem *self = (GbpMesonBuildSystem *)build_system;
+
+  g_return_val_if_fail (IDE_IS_MAIN_THREAD (), NULL);
+  g_return_val_if_fail (GBP_IS_MESON_BUILD_SYSTEM (self), NULL);
+
+  return g_strdup (self->project_version);
+}
+
 static void
 build_system_iface_init (IdeBuildSystemInterface *iface)
 {
@@ -686,9 +734,57 @@ build_system_iface_init (IdeBuildSystemInterface *iface)
   iface->get_build_flags_for_files_async = gbp_meson_build_system_get_build_flags_for_files_async;
   iface->get_build_flags_for_files_finish = gbp_meson_build_system_get_build_flags_for_files_finish;
   iface->get_builddir = gbp_meson_build_system_get_builddir;
+  iface->get_project_version = gbp_meson_build_system_get_project_version;
   iface->supports_toolchain = gbp_meson_build_system_supports_toolchain;
 }
 
+static void
+extract_metadata (GbpMesonBuildSystem *self,
+                  const gchar         *contents)
+{
+  const gchar *ptr;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (GBP_IS_MESON_BUILD_SYSTEM (self));
+  g_assert (contents != NULL);
+
+  ptr = strstr (contents, "version:");
+
+  if (ptr > contents)
+    {
+      const gchar *prev = ptr - 1;
+      gunichar ch = g_utf8_get_char (prev);
+
+      if (g_unichar_isspace (ch) || ch == ',')
+        {
+          const gchar *begin;
+          const gchar *end;
+
+          ptr++;
+
+          for (ptr++; *ptr && *ptr != '\''; ptr = g_utf8_next_char (ptr)) ;
+          if (!*ptr)
+            goto failure;
+
+          ptr++;
+          begin = ptr;
+
+          for (ptr++; *ptr && *ptr != '\''; ptr = g_utf8_next_char (ptr)) ;
+          if (!*ptr)
+            goto failure;
+
+          end = ptr;
+
+          g_free (self->project_version);
+          self->project_version = g_strndup (begin, end - begin);
+        }
+    }
+
+failure:
+
+  return;
+}
+
 static void
 gbp_meson_build_system_notify_pipeline (GbpMesonBuildSystem *self,
                                         GParamSpec          *pspec,
@@ -718,8 +814,10 @@ gbp_meson_build_system_init_async (GAsyncInitable      *initable,
 {
   GbpMesonBuildSystem *self = (GbpMesonBuildSystem *)initable;
   g_autoptr(IdeTask) task = NULL;
+  g_autofree gchar *contents = NULL;
   IdeBuildManager *build_manager;
   IdeContext *context;
+  gsize len = 0;
 
   IDE_ENTRY;
 
@@ -738,6 +836,9 @@ gbp_meson_build_system_init_async (GAsyncInitable      *initable,
   ide_task_set_priority (task, io_priority);
   ide_task_set_task_data (task, g_object_ref (self->project_file), g_object_unref);
 
+  if (g_file_load_contents (self->project_file, cancellable, &contents, &len, NULL, NULL))
+    extract_metadata (self, contents);
+
   /*
    * We want to be notified of any changes to the current build manager.
    * This will let us invalidate our compile_commands.json when it changes.
