@@ -29,6 +29,8 @@
 #include <libide-tree.h>
 #include <libide-vcs.h>
 
+#include "ide-tree-private.h"
+
 #include "gbp-project-tree-addin.h"
 
 struct _GbpProjectTreeAddin
@@ -348,8 +350,8 @@ collect_files (GFile *file,
 }
 
 static int
-node_compare (IdeTreeNode *node,
-              IdeTreeNode *child)
+node_compare_directories_first (IdeTreeNode *node,
+                                IdeTreeNode *child)
 {
   gint cmp;
   const gchar *child_name, *node_name;
@@ -382,6 +384,28 @@ node_compare (IdeTreeNode *node,
   return cmp > 0 ? cmp : 0;
 }
 
+static int
+node_compare (IdeTreeNode *node,
+              IdeTreeNode *child)
+{
+  gint cmp;
+  const gchar *child_name, *node_name;
+  g_autofree gchar *collated_child = NULL;
+  g_autofree gchar *collated_node = NULL;
+
+  g_assert (IDE_IS_TREE_NODE (node));
+  g_assert (IDE_IS_TREE_NODE (child));
+
+  child_name = ide_tree_node_get_display_name (child);
+  node_name = ide_tree_node_get_display_name (node);
+
+  collated_child = g_utf8_collate_key_for_filename (child_name, -1);
+  collated_node = g_utf8_collate_key_for_filename (node_name, -1);
+
+  cmp = g_strcmp0 (collated_child, collated_node);
+
+  return cmp > 0 ? cmp : 0;
+}
 
 static void
 gbp_project_tree_addin_add_file (GbpProjectTreeAddin *self,
@@ -453,7 +477,10 @@ gbp_project_tree_addin_add_file (GbpProjectTreeAddin *self,
       project_file = ide_project_file_new (directory, info);
       node = create_file_node (project_file);
 
-      ide_tree_node_insert_sorted (parent, node, node_compare);
+      if (self->sort_directories_first)
+        ide_tree_node_insert_sorted (parent, node, node_compare_directories_first);
+      else
+        ide_tree_node_insert_sorted (parent, node, node_compare);
 
       if (!ide_tree_node_expanded (self->tree, parent))
         ide_tree_expand_node (self->tree, parent);
@@ -482,7 +509,16 @@ gbp_project_tree_addin_remove_file (GbpProjectTreeAddin *self,
 #endif
 
   if ((selected = find_file_node (self->tree, file)))
-    ide_tree_node_remove (ide_tree_node_get_parent (selected), selected);
+    {
+      IdeTreeNode *parent = ide_tree_node_get_parent (selected);
+
+      ide_tree_node_remove (parent, selected);
+
+      /* Force the parent node to re-add the Empty child */
+      if (ide_tree_node_get_children_possible (parent) &&
+          ide_tree_node_get_n_children (parent) == 0)
+        _ide_tree_node_remove_all (parent);
+    }
 
   IDE_EXIT;
 }
