@@ -23,16 +23,19 @@
 #include <glib/gi18n.h>
 #include <libide-greeter.h>
 
-#include "gbp-recent-project-row.h"
+#include "ide-truncate-model.h"
+
 #include "gbp-recent-section.h"
 
 struct _GbpRecentSection
 {
-  GtkBin      parent_instance;
+  GtkBin            parent_instance;
 
-  GtkListBox *listbox;
+  IdeTruncateModel *truncate;
 
-  guint       selection_mode : 1;
+  GtkListBox       *listbox;
+
+  guint             selection_mode : 1;
 };
 
 enum {
@@ -90,7 +93,7 @@ gbp_recent_section_get_has_selection (GbpRecentSection *self)
 static gint
 gbp_recent_section_get_priority (IdeGreeterSection *section)
 {
-  return 0;
+  return -100;
 }
 
 static void
@@ -103,15 +106,17 @@ gbp_recent_section_filter_cb (GtkListBoxRow *row,
   } *filter = user_data;
   gboolean match = TRUE;
 
-  g_assert (GBP_IS_RECENT_PROJECT_ROW (row));
+  if (!IDE_IS_GREETER_ROW (row))
+    return;
+
   g_assert (filter != NULL);
 
   if (filter->spec != NULL)
     {
-      const gchar *search_text;
+      g_autofree gchar *search_text = NULL;
 
-      search_text = gbp_recent_project_row_get_search_text (GBP_RECENT_PROJECT_ROW (row));
-      match = dzl_pattern_spec_match (filter->spec, search_text);
+      if ((search_text = ide_greeter_row_get_search_text (IDE_GREETER_ROW (row))))
+        match = dzl_pattern_spec_match (filter->spec, search_text);
     }
 
   gtk_widget_set_visible (GTK_WIDGET (row), match);
@@ -131,6 +136,10 @@ gbp_recent_section_filter (IdeGreeterSection *section,
 
   g_assert (GBP_IS_RECENT_SECTION (self));
 
+  /* Expand the truncation model if necessary */
+  if (spec != NULL)
+    ide_truncate_model_set_expanded (self->truncate, TRUE);
+
   /* We don't use filter func here so that we know if any
    * rows matched. We have to hide our widget if there are
    * no visible matches.
@@ -153,13 +162,14 @@ gbp_recent_section_activate_first_cb (GtkWidget *widget,
     gboolean handled;
   } *activate = user_data;
 
-  g_assert (GBP_IS_RECENT_PROJECT_ROW (widget));
   g_assert (activate != NULL);
 
-  if (activate->handled || !gtk_widget_get_visible (widget))
+  if (!IDE_IS_GREETER_ROW (widget) ||
+      activate->handled ||
+      !gtk_widget_get_visible (widget))
     return;
 
-  project_info = gbp_recent_project_row_get_project_info (GBP_RECENT_PROJECT_ROW (widget));
+  project_info = ide_greeter_row_get_project_info (IDE_GREETER_ROW (widget));
   ide_greeter_section_emit_project_activated (IDE_GREETER_SECTION (activate->self), project_info);
 
   activate->handled = TRUE;
@@ -190,13 +200,15 @@ static void
 gbp_recent_section_set_selection_mode_cb (GtkWidget *widget,
                                           gpointer   user_data)
 {
-  GbpRecentProjectRow *row = (GbpRecentProjectRow *)widget;
+  IdeGreeterRow *row = (IdeGreeterRow *)widget;
   gboolean *selection_mode = user_data;
 
-  g_assert (GBP_IS_RECENT_PROJECT_ROW (row));
   g_assert (selection_mode != NULL);
 
-  gbp_recent_project_row_set_selection_mode (row, *selection_mode);
+  if (!IDE_IS_GREETER_ROW (row))
+    return;
+
+  ide_greeter_row_set_selection_mode (row, *selection_mode);
   g_object_set (row, "selected", FALSE, NULL);
 }
 
@@ -221,20 +233,22 @@ static void
 gbp_recent_section_collect_selected_cb (GtkWidget *widget,
                                         gpointer   user_data)
 {
-  GbpRecentProjectRow *row = (GbpRecentProjectRow *)widget;
+  IdeGreeterRow *row = (IdeGreeterRow *)widget;
   GList **list = user_data;
   gboolean selected = FALSE;
 
-  g_assert (GBP_IS_RECENT_PROJECT_ROW (row));
   g_assert (list != NULL);
 
+  if (!IDE_IS_GREETER_ROW (row))
+    return;
+
   g_object_get (row, "selected", &selected, NULL);
 
   if (selected)
     {
       IdeProjectInfo *project_info;
 
-      project_info = gbp_recent_project_row_get_project_info (row);
+      project_info = ide_greeter_row_get_project_info (row);
       *list = g_list_prepend (*list, g_object_ref (project_info));
       gtk_widget_destroy (GTK_WIDGET (row));
     }
@@ -459,12 +473,14 @@ gbp_recent_section_purge_selected_full (IdeGreeterSection *section,
       gtk_box_set_spacing (GTK_BOX (content_area), 12);
 
       scroller = gtk_scrolled_window_new (NULL, NULL);
+      gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroller), GTK_SHADOW_IN);
       gtk_widget_set_vexpand (scroller, TRUE);
       gtk_container_add (GTK_CONTAINER (content_area), scroller);
       gtk_widget_show (scroller);
 
       view = gtk_text_view_new ();
       gtk_text_view_set_editable (GTK_TEXT_VIEW (view), FALSE);
+      gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
       buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
       gtk_container_add (GTK_CONTAINER (scroller), view);
       gtk_widget_show (view);
@@ -519,25 +535,30 @@ G_DEFINE_TYPE_WITH_CODE (GbpRecentSection, gbp_recent_section, GTK_TYPE_BIN,
                                                 greeter_section_iface_init))
 
 static void
-gbp_recent_section_notify_row_selected (GbpRecentSection    *self,
-                                        GParamSpec          *pspec,
-                                        GbpRecentProjectRow *row)
+gbp_recent_section_notify_row_selected (GbpRecentSection *self,
+                                        GParamSpec       *pspec,
+                                        IdeGreeterRow    *row)
 {
   g_assert (GBP_IS_RECENT_SECTION (self));
-  g_assert (GBP_IS_RECENT_PROJECT_ROW (row));
+  g_assert (IDE_IS_GREETER_ROW (row));
 
   g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_HAS_SELECTION]);
 }
 
 static void
-gbp_recent_section_row_activated (GbpRecentSection    *self,
-                                  GbpRecentProjectRow *row,
-                                  GtkListBox          *list_box)
+gbp_recent_section_row_activated (GbpRecentSection *self,
+                                  IdeGreeterRow    *row,
+                                  GtkListBox       *list_box)
 {
   g_assert (GBP_IS_RECENT_SECTION (self));
-  g_assert (GBP_IS_RECENT_PROJECT_ROW (row));
   g_assert (GTK_IS_LIST_BOX (list_box));
 
+  if (!IDE_IS_GREETER_ROW (row))
+    {
+      ide_truncate_model_set_expanded (self->truncate, TRUE);
+      return;
+    }
+
   if (self->selection_mode)
     {
       gboolean selected = FALSE;
@@ -549,7 +570,7 @@ gbp_recent_section_row_activated (GbpRecentSection    *self,
     {
       IdeProjectInfo *project_info;
 
-      project_info = gbp_recent_project_row_get_project_info (row);
+      project_info = ide_greeter_row_get_project_info (row);
       ide_greeter_section_emit_project_activated (IDE_GREETER_SECTION (self), project_info);
     }
 }
@@ -559,13 +580,13 @@ create_widget_func (gpointer item,
                     gpointer user_data)
 {
   IdeProjectInfo *project_info = item;
-  GbpRecentProjectRow *row;
   GbpRecentSection *self = user_data;
+  IdeGreeterRow *row;
 
   g_assert (IDE_IS_PROJECT_INFO (project_info));
   g_assert (GBP_IS_RECENT_SECTION (self));
 
-  row = g_object_new (GBP_TYPE_RECENT_PROJECT_ROW,
+  row = g_object_new (IDE_TYPE_GREETER_ROW,
                       "project-info", project_info,
                       "visible", TRUE,
                       NULL);
@@ -576,22 +597,53 @@ create_widget_func (gpointer item,
                            self,
                            G_CONNECT_SWAPPED);
 
+  if (self->selection_mode)
+    ide_greeter_row_set_selection_mode (row, TRUE);
+
   return GTK_WIDGET (row);
 }
 
+static void
+gbp_recent_section_destroy (GtkWidget *widget)
+{
+  GbpRecentSection *self = (GbpRecentSection *)widget;
+
+  g_clear_object (&self->truncate);
+
+  GTK_WIDGET_CLASS (gbp_recent_section_parent_class)->destroy (widget);
+}
+
 static void
 gbp_recent_section_constructed (GObject *object)
 {
   GbpRecentSection *self = (GbpRecentSection *)object;
   IdeRecentProjects *projects;
+  GtkListBoxRow *row;
+  GtkImage *image;
 
   G_OBJECT_CLASS (gbp_recent_section_parent_class)->constructed (object);
 
   projects = ide_recent_projects_get_default ();
 
+  self->truncate = ide_truncate_model_new (G_LIST_MODEL (projects));
+
   gtk_list_box_bind_model (self->listbox,
-                           G_LIST_MODEL (projects),
+                           G_LIST_MODEL (self->truncate),
                            create_widget_func, self, NULL);
+
+  row = g_object_new (GTK_TYPE_LIST_BOX_ROW,
+                      "visible", TRUE,
+                      NULL);
+  image = g_object_new (GTK_TYPE_IMAGE,
+                        "margin", 8,
+                        "icon-name", "view-more-symbolic",
+                        "visible", TRUE,
+                        NULL);
+  gtk_container_add (GTK_CONTAINER (row), GTK_WIDGET (image));
+  gtk_container_add (GTK_CONTAINER (self->listbox), GTK_WIDGET (row));
+
+  g_object_bind_property (self->truncate, "can-expand", row, "visible",
+                          G_BINDING_SYNC_CREATE);
 }
 
 static void
@@ -622,6 +674,8 @@ gbp_recent_section_class_init (GbpRecentSectionClass *klass)
   object_class->constructed = gbp_recent_section_constructed;
   object_class->get_property = gbp_recent_section_get_property;
 
+  widget_class->destroy = gbp_recent_section_destroy;
+
   properties [PROP_HAS_SELECTION] =
     g_param_spec_boolean ("has-selection", NULL, NULL,
                           FALSE,
@@ -633,8 +687,6 @@ gbp_recent_section_class_init (GbpRecentSectionClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class, "/plugins/recent/gbp-recent-section.ui");
   gtk_widget_class_bind_template_child (widget_class, GbpRecentSection, listbox);
   gtk_widget_class_bind_template_callback (widget_class, gbp_recent_section_row_activated);
-
-  g_type_ensure (GBP_TYPE_RECENT_PROJECT_ROW);
 }
 
 static gboolean
